@@ -34,6 +34,12 @@ test(IC_st, joint = TRUE)
 contrast(emmeans(noise.lm, ~ size*type*side),
          interaction = c("poly", "consec", "consec"))
 
+## ------------------------------------------------------------------------
+joint_tests(noise.lm)
+
+## ------------------------------------------------------------------------
+joint_tests(noise.lm, by = "side")
+
 ## ------------------------------------------------------------------------
 org.quad <- lm(cbind(sales1, sales2) ~ poly(price1, price2, degree = 2)
                                        + day + store, data = oranges)
